# seqq
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.18
- Package version: 0.0.30
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/jjti/seqq-python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/jjti/seqq-python.git`)

Then import the package:
```python
import seqq
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import seqq
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import seqq
from seqq.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = seqq.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
with seqq.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = seqq.SeqqServiceApi(api_client)
    collection = 'collection_example' # str | The `name` of the Collection to create Sequences in. Format: `collections/{collection_id}`.
    body = seqq.SeqqServiceBatchCreateSequencesRequest() # SeqqServiceBatchCreateSequencesRequest | 

    try:
        # Create a batch of Sequences in a Collection.
        api_response = api_instance.batch_create_sequences(collection, body)
        print("The response of SeqqServiceApi->batch_create_sequences:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling SeqqServiceApi->batch_create_sequences: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*SeqqServiceApi* | [**batch_create_sequences**](docs/SeqqServiceApi.md#batch_create_sequences) | **POST** /v1alpha/{collection}/sequences:batchCreate | Create a batch of Sequences in a Collection.
*SeqqServiceApi* | [**create_collection**](docs/SeqqServiceApi.md#create_collection) | **POST** /v1alpha/collections | Create a Collection.
*SeqqServiceApi* | [**create_integration**](docs/SeqqServiceApi.md#create_integration) | **POST** /v1alpha/{collection}/integrations | Create an Integration.
*SeqqServiceApi* | [**create_sequence**](docs/SeqqServiceApi.md#create_sequence) | **POST** /v1alpha/{collection}/sequences | Create a Sequence in a Collection.
*SeqqServiceApi* | [**delete_collection**](docs/SeqqServiceApi.md#delete_collection) | **DELETE** /v1alpha/{name} | Delete a Collection by name.
*SeqqServiceApi* | [**delete_integration**](docs/SeqqServiceApi.md#delete_integration) | **DELETE** /v1alpha/{name_3} | Delete an Integration by name.
*SeqqServiceApi* | [**delete_search**](docs/SeqqServiceApi.md#delete_search) | **DELETE** /v1alpha/{name_2} | Delete a Search by name.
*SeqqServiceApi* | [**delete_sequence**](docs/SeqqServiceApi.md#delete_sequence) | **DELETE** /v1alpha/{name_1} | Delete a Sequence by name.
*SeqqServiceApi* | [**get_collection**](docs/SeqqServiceApi.md#get_collection) | **GET** /v1alpha/{name} | Get a Collection by its name.
*SeqqServiceApi* | [**get_integration**](docs/SeqqServiceApi.md#get_integration) | **GET** /v1alpha/{name_3} | Get an Integration by name.
*SeqqServiceApi* | [**get_search**](docs/SeqqServiceApi.md#get_search) | **GET** /v1alpha/{name_2} | Get a Search by name.
*SeqqServiceApi* | [**get_sequence**](docs/SeqqServiceApi.md#get_sequence) | **GET** /v1alpha/{name_1} | Get a Sequence by name.
*SeqqServiceApi* | [**list_collections**](docs/SeqqServiceApi.md#list_collections) | **GET** /v1alpha/collections | List Collections.
*SeqqServiceApi* | [**list_integrations**](docs/SeqqServiceApi.md#list_integrations) | **GET** /v1alpha/{collection}/integrations | List Integrations in a Collection.
*SeqqServiceApi* | [**list_searches**](docs/SeqqServiceApi.md#list_searches) | **GET** /v1alpha/{collection}/searches | List Searches in a Collection.
*SeqqServiceApi* | [**list_sequences**](docs/SeqqServiceApi.md#list_sequences) | **GET** /v1alpha/{collection}/sequences | List Sequences in a Collection.
*SeqqServiceApi* | [**start_search**](docs/SeqqServiceApi.md#start_search) | **POST** /v1alpha/{collection}/searches | Start a Search asynchronously.
*SeqqServiceApi* | [**update_integration**](docs/SeqqServiceApi.md#update_integration) | **PATCH** /v1alpha/{integration.name} | Update an Integration.


## Documentation For Models

 - [ProtobufAny](docs/ProtobufAny.md)
 - [RpcStatus](docs/RpcStatus.md)
 - [SearchState](docs/SearchState.md)
 - [SeqqServiceBatchCreateSequencesRequest](docs/SeqqServiceBatchCreateSequencesRequest.md)
 - [TheIntegrationToUpdate](docs/TheIntegrationToUpdate.md)
 - [V1alphaBatchCreateSequencesResponse](docs/V1alphaBatchCreateSequencesResponse.md)
 - [V1alphaCode](docs/V1alphaCode.md)
 - [V1alphaCollection](docs/V1alphaCollection.md)
 - [V1alphaCreateSequenceRequest](docs/V1alphaCreateSequenceRequest.md)
 - [V1alphaCreateSequencesFromFileResponse](docs/V1alphaCreateSequencesFromFileResponse.md)
 - [V1alphaFileEncoding](docs/V1alphaFileEncoding.md)
 - [V1alphaHit](docs/V1alphaHit.md)
 - [V1alphaIntegration](docs/V1alphaIntegration.md)
 - [V1alphaIntegrationGoogleDrive](docs/V1alphaIntegrationGoogleDrive.md)
 - [V1alphaIntegrationNCBI](docs/V1alphaIntegrationNCBI.md)
 - [V1alphaListCollectionsResponse](docs/V1alphaListCollectionsResponse.md)
 - [V1alphaListIntegrationsResponse](docs/V1alphaListIntegrationsResponse.md)
 - [V1alphaListSearchesResponse](docs/V1alphaListSearchesResponse.md)
 - [V1alphaListSequencesResponse](docs/V1alphaListSequencesResponse.md)
 - [V1alphaSearch](docs/V1alphaSearch.md)
 - [V1alphaSequence](docs/V1alphaSequence.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




